@@ -13,6 +13,21 @@ class LedMode(Enum):
     OFF = 4
 
 
+@unique
+class EcoShutdown(Enum):
+    ONE_HOUR = 1
+    TWO_HOURS = 2
+    THREE_HOURS = 3
+    FOUR_HOURS = 4
+
+
+@unique
+class ChargingMode(Enum):
+    STANDARD = 0
+    SILENT = 1
+    TURBO = 2
+
+
 class EB3A(BluettiDevice):
     def __init__(self, address: str, sn: str):
         self.struct = DeviceStruct()
@@ -26,14 +41,14 @@ class EB3A(BluettiDevice):
         self.struct.add_uint_field('ac_input_power', 0x00, 0x25)
         self.struct.add_uint_field('ac_output_power', 0x00, 0x26)
         self.struct.add_uint_field('dc_output_power', 0x00, 0x27)
-        self.struct.add_decimal_field('power_generation', 0x00, 0x29, 1) # Total power generated since last reset in kwh
+        self.struct.add_decimal_field('power_generation', 0x00, 0x29, 1)  # Total power generated since last reset (kwh)
         self.struct.add_uint_field('total_battery_percent', 0x00, 0x2B)
         self.struct.add_bool_field('ac_output_on', 0x00, 0x30)
         self.struct.add_bool_field('dc_output_on', 0x00, 0x31)
 
         # Page 0x00 - Details
         self.struct.add_decimal_field('ac_input_voltage', 0x00, 0x4D, 1)
-        self.struct.add_decimal_field('dc_input_voltage', 0x00, 0x56, 1)
+        self.struct.add_decimal_field('internal_dc_input_voltage', 0x00, 0x56, 2)
 
         # Page 0x00 - Battery Data
         self.struct.add_uint_field('pack_num_max', 0x00, 0x5B)
@@ -42,6 +57,11 @@ class EB3A(BluettiDevice):
         self.struct.add_bool_field('ac_output_on', 0x0B, 0xBF)
         self.struct.add_bool_field('dc_output_on', 0x0B, 0xC0)
         self.struct.add_enum_field('led_mode', 0x0B, 0xDA, LedMode)
+        self.struct.add_bool_field('power_off', 0x0B, 0xF4)
+        self.struct.add_bool_field('eco_on', 0x0B, 0xF7)
+        self.struct.add_enum_field('eco_shutdown', 0x0B, 0xF8, EcoShutdown)
+        self.struct.add_enum_field('charging_mode', 0x0B, 0xF9, ChargingMode)
+        self.struct.add_bool_field('power_lifting_on', 0x0B, 0xFA)
 
         super().__init__(address, 'EB3A', sn)
 
@@ -50,7 +70,8 @@ class EB3A(BluettiDevice):
         return [
             QueryRangeCommand(0x00, 0x0A, 0x28),
             QueryRangeCommand(0x00, 0x46, 0x15),
-            QueryRangeCommand(0x0B, 0xDA, 1)
+            QueryRangeCommand(0x0B, 0xDA, 0x01),
+            QueryRangeCommand(0x0B, 0xF4, 0x07)
         ]
 
     @property
@@ -59,6 +80,5 @@ class EB3A(BluettiDevice):
             QueryRangeCommand(0x00, 0x0A, 0x35),
             QueryRangeCommand(0x00, 0x46, 0x42),
             QueryRangeCommand(0x00, 0x88, 0x4A),
-            QueryRangeCommand(0x0B, 0xB9, 0x3D)
+            QueryRangeCommand(0x0B, 0xB8, 0x43)
         ]
-
